package com.cebbank.mft.client.core.module.system;

import com.cebbank.mft.client.core.module.system.ISystemModule;
import java.io.File;
import java.net.URLDecoder;
import java.nio.file.Paths;
import java.text.SimpleDateFormat;
import java.util.Date;
import javax.annotation.PostConstruct;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

@Component
public class SystemModuleImpl implements ISystemModule {

   private static final Logger log = LogManager.getLogger(SystemModuleImpl.class);
   private String UPLOAD_CHECK_POINT_DIR;
   private String DOWNLOAD_CHECK_POINT_DIR;
   private String PRIVATE_KEY_PATH;
   private String CURRENT_CLIENT_DIR;
   private String ROOT_CLIENT_DIR;
   private String DATA_PATH;
   @Value("${client.type}")
   private String currentClientType;
   @Value("${client.version}")
   private String currentClientVersion;
   @Value("${jobManager.concurrency}")
   private int jobManagerConcurrency;
   @Value("${sdk.workerNum}")
   private int sdkWorkerNum;


   @PostConstruct
   public void init() {
      String path = SystemModuleImpl.class.getProtectionDomain().getCodeSource().getLocation().getFile();

      try {
         path = URLDecoder.decode(path, "UTF-8");
         File paths = new File(path);
         path = paths.getParent();
      } catch (Exception var5) {
         throw new UnsupportedOperationException(var5);
      }

      this.CURRENT_CLIENT_DIR = path;
      log.info("CURRENT_CLIENT_DIR = {}", this.CURRENT_CLIENT_DIR);
      if(Paths.get(this.CURRENT_CLIENT_DIR, new String[0]).getParent() == null) {
         throw new UnsupportedOperationException("not support install client to root dir " + this.CURRENT_CLIENT_DIR);
      } else {
         this.ROOT_CLIENT_DIR = Paths.get(this.CURRENT_CLIENT_DIR, new String[0]).getParent().toString();
         log.info("ROOT_CLIENT_DIR = {}", this.ROOT_CLIENT_DIR);
         this.DATA_PATH = System.getProperty("user.dir") + File.separator + "data";
         this.UPLOAD_CHECK_POINT_DIR = this.DATA_PATH + File.separator + "ucp";
         this.DOWNLOAD_CHECK_POINT_DIR = this.DATA_PATH + File.separator + "dcp";
         this.PRIVATE_KEY_PATH = this.DATA_PATH + File.separator + "vkkey";
         String[] var6 = new String[]{this.UPLOAD_CHECK_POINT_DIR, this.DOWNLOAD_CHECK_POINT_DIR, this.PRIVATE_KEY_PATH};

         for(int i = 0; i < var6.length; ++i) {
            File f = new File(var6[i]);
            f.mkdirs();
            log.info("init data dir {}", var6[i]);
         }

      }
   }

   public String getCurrentClientDir() {
      return this.CURRENT_CLIENT_DIR;
   }

   public String getRootClientDir() {
      return this.ROOT_CLIENT_DIR;
   }

   public String getDataPath() {
      return this.DATA_PATH;
   }

   public String getPrivateKeyStorePath(int siteId) {
      SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
      return this.PRIVATE_KEY_PATH + File.separator + siteId + File.separator + sdf.format(new Date());
   }

   public String getDownloadCheckpointFilePath(long jobId, int taskSequence) {
      return this.DOWNLOAD_CHECK_POINT_DIR + File.separator + String.format("job-%d-task-%d.dcp", new Object[]{Long.valueOf(jobId), Integer.valueOf(taskSequence)});
   }

   public String getUploadCheckpointFilePath(long jobId, int taskSequence) {
      return this.UPLOAD_CHECK_POINT_DIR + File.separator + String.format("job-%d-task-%d.ucp", new Object[]{Long.valueOf(jobId), Integer.valueOf(taskSequence)});
   }

   public int getSDKWorkerNum() {
      return this.sdkWorkerNum;
   }

   public int getJobManagerConcurrency() {
      return this.jobManagerConcurrency;
   }

   public String getCurrentClientType() {
      return this.currentClientType;
   }

   public String getCurrentClientVersion() {
      return this.currentClientVersion;
   }

}
